# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, PropsDictType, Tags


class RuleGroupsNamespace(AWSObject):
    """
    `RuleGroupsNamespace <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aps-rulegroupsnamespace.html>`__
    """

    resource_type = "AWS::APS::RuleGroupsNamespace"

    props: PropsDictType = {
        "Data": (str, True),
        "Name": (str, True),
        "Tags": (Tags, False),
        "Workspace": (str, True),
    }


class Workspace(AWSObject):
    """
    `Workspace <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aps-workspace.html>`__
    """

    resource_type = "AWS::APS::Workspace"

    props: PropsDictType = {
        "AlertManagerDefinition": (str, False),
        "Alias": (str, False),
        "Tags": (Tags, False),
    }
