# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***
# Resource specification version: 46.0.0


from troposphere import Tags

from . import AWSObject, AWSProperty
from .validators import boolean


class ManifestOverridesPayload(AWSProperty):
    props = {
        "PayloadData": (str, False),
    }


class ManifestPayload(AWSProperty):
    props = {
        "PayloadData": (str, False),
    }


class ApplicationInstance(AWSObject):
    resource_type = "AWS::Panorama::ApplicationInstance"

    props = {
        "ApplicationInstanceIdToReplace": (str, False),
        "DefaultRuntimeContextDevice": (str, True),
        "Description": (str, False),
        "DeviceId": (str, False),
        "ManifestOverridesPayload": (ManifestOverridesPayload, False),
        "ManifestPayload": (ManifestPayload, True),
        "Name": (str, False),
        "RuntimeRoleArn": (str, False),
        "StatusFilter": (str, False),
        "Tags": (Tags, False),
    }


class Package(AWSObject):
    resource_type = "AWS::Panorama::Package"

    props = {
        "PackageName": (str, True),
        "Tags": (Tags, False),
    }


class PackageVersion(AWSObject):
    resource_type = "AWS::Panorama::PackageVersion"

    props = {
        "MarkLatest": (boolean, False),
        "OwnerAccount": (str, False),
        "PackageId": (str, True),
        "PackageVersion": (str, True),
        "PatchVersion": (str, True),
        "UpdatedLatestPatchVersion": (str, False),
    }
