# Copyright (c) 2012-2019, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***
# Resource specification version: 4.1.0


from . import AWSObject
from .validators import json_checker


class Hub(AWSObject):
    resource_type = "AWS::SecurityHub::Hub"

    props = {
        "Tags": (json_checker, False),
    }
