# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, PropsDictType, Tags
from .validators import integer


class InferenceScheduler(AWSObject):
    """
    `InferenceScheduler <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lookoutequipment-inferencescheduler.html>`__
    """

    resource_type = "AWS::LookoutEquipment::InferenceScheduler"

    props: PropsDictType = {
        "DataDelayOffsetInMinutes": (integer, False),
        "DataInputConfiguration": (dict, True),
        "DataOutputConfiguration": (dict, True),
        "DataUploadFrequency": (str, True),
        "InferenceSchedulerName": (str, False),
        "ModelName": (str, True),
        "RoleArn": (str, True),
        "ServerSideKmsKeyId": (str, False),
        "Tags": (Tags, False),
    }
